pub fn register_xlib_error_hook(
    hook: Box<dyn Fn(*mut c_void, *mut c_void) -> bool + Sync + Send>
)
Hook to winit’s xlib error handling callback.

This method is provided as a safe way to handle the errors comming from X11 when using xlib in external crates, like glutin for GLX access. Trying to handle errors by speculating with XSetErrorHandler is unsafe.